#
# spec file for package php7-imagick
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    imagick
Name:           php7-%{pkg_name}
Version:        3.4.4
Release:        lp151.8.3.1
Summary:        Wrapper to the ImageMagick library
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/imagick
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        %{pkg_name}.ini
Patch0:         imagick-reproducible.patch
BuildRequires:  ImageMagick-devel >= 6.5.3.10
BuildRequires:  ghostscript-fonts-std
BuildRequires:  php7-devel >= 7.0.1
BuildRequires:  re2c
Conflicts:      php7-gmagick
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}
%if %{?php_zend_api}0
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
%else
%requires_eq    php7
%endif

%description
PHP extension to create, modify and obtain meta information of images using
the ImageMagick API

%prep
%setup -q -n %{pkg_name}-%{version}
%patch0 -p1
mkdir %{name}
# Ignore know failed test on OBS with timeout
rm tests/229_Tutorial_fxAnalyzeImage_case1.phpt

%build
%{_bindir}/phpize
export CFLAGS="%{optflags} -fvisibility=hidden"
%configure --with-%{pkg_name}=%{_usr}
make %{?_smp_mflags}

%check
%if 0%{?qemu_user_space_build}
export TEST_TIMEOUT=600
%endif
make %{?_smp_mflags} PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test \
	|| { for f in tests/*.out; do cat $f; echo '------'; done; exit 1; }

%install
make DESTDIR=%{buildroot} install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/php7/conf.d
install --mode=0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/php7/conf.d/%{pkg_name}.ini

# remove not used header file(s)
rm -rf %{buildroot}/%{_includedir}/php7/ext/%{pkg_name}/

%files
%defattr(0644,root,root,-)
%{_libdir}/php7/extensions/%{pkg_name}.so
%config(noreplace) %{_sysconfdir}/php7/conf.d/%{pkg_name}.ini
%license LICENSE
%doc ChangeLog CREDITS

%changelog
* Tue May  7 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- removed patch imagic-3.4.3-relax_test_150_to_follow_upstream_change.patch
  which is no longer necessary.
- Upgrade to version 3.4.4
  Added:
  * function Imagick::optimizeImageTransparency()
  * METRIC_STRUCTURAL_SIMILARITY_ERROR
  * METRIC_STRUCTURAL_DISSIMILARITY_ERROR
  * COMPRESSION_ZSTD - https://github.com/facebook/zstd
  * COMPRESSION_WEBP
  * CHANNEL_COMPOSITE_MASK
  * FILTER_CUBIC_SPLINE - "Define the lobes with the -define
    filter:lobes={2,3,4}
    (reference https://imagemagick.org/discourse-server/viewtopic.php?f=2&t=32506)."
  * Imagick now explicitly conflicts with the Gmagick extension.
  Fixes:
  * Correct version check to make RemoveAlphaChannel and FlattenAlphaChannel
    be available when using Imagick with ImageMagick version 6.7.8-x
  * Bug 77128 - Imagick::setImageInterpolateMethod() not available on Windows
  * Prevent memory leak when ImagickPixel::__construct called after object instantiation.
  * Prevent segfault when ImagickPixel internal constructor not called.
  * Imagick::setResourceLimit support for values larger than 2GB (2^31) on 32bit platforms.
  * Corrected memory overwrite in Imagick::colorDecisionListImage()
  * Bug 77791 - ImagickKernel::fromMatrix() out of bounds write.
    Fixes CVE-2019-11037, boo#1135418
  The following functions have been deprecated:
  * ImagickDraw, matte
  * Imagick::averageimages
  * Imagick::colorfloodfillimage
  * Imagick::filter
  * Imagick::flattenimages
  * Imagick::getimageattribute
  * Imagick::getimagechannelextrema
  * Imagick::getimageclipmask
  * Imagick::getimageextrema
  * Imagick::getimageindex
  * Imagick::getimagematte
  * Imagick::getimagemattecolor
  * Imagick::getimagesize
  * Imagick::mapimage
  * Imagick::mattefloodfillimage
  * Imagick::medianfilterimage
  * Imagick::mosaicimages
  * Imagick::orderedposterizeimage
  * Imagick::paintfloodfillimage
  * Imagick::paintopaqueimage
  * Imagick::painttransparentimage
  * Imagick::radialblurimage
  * Imagick::recolorimage
  * Imagick::reducenoiseimage
  * Imagick::roundcornersimage
  * Imagick::roundcorners
  * Imagick::setimageattribute
  * Imagick::setimagebias
  * Imagick::setimageclipmask
  * Imagick::setimageindex
  * Imagick::setimagemattecolor
  * Imagick::setimagebiasquantum
  * Imagick::setimageopacity
  * Imagick::transformimage
* Tue Feb 12 2019 schwab@suse.de
- Use bigger timeout when running under qemu
* Wed May  9 2018 jweberhofer@weberhofer.at
- removed Test 229 which fails occasionally with timeouts
  on the OBS build server
* Mon May  7 2018 jweberhofer@weberhofer.at
- Print test failures in detail
* Sun May  6 2018 jweberhofer@weberhofer.at
  Fixes for bnc#1091929
- Due to a packaging change in ghostscript the ghostscript-fonts-std
  has to be included explicitly to successfully run the tests. Elsewise
  the required helvetica-font is missing.
- ImageMagick's commit 97a319 makes ImagaMagick to no longer throw an
  an exception if image registry tag is not found.
  Added imagic-3.4.3-relax_test_150_to_follow_upstream_change.patch
* Fri Mar 16 2018 crrodriguez@opensuse.org
- Build module with fvisibility=hidden, this should
  avoid additional symbol conflicts.
* Fri Mar 16 2018 crrodriguez@opensuse.org
- add a Conflict between this extension and gmagick.
  (boo#1085595)
* Thu Mar  8 2018 ilya@ilya.pp.ua
- Add %%licence macros.
* Tue Mar  6 2018 crrodriguez@opensuse.org
- remove double ./configure and build
- imagick-reproducible.patch: We only care if ImageMagick
  is binary compatible, not about what version the extension
  is compiled against, which changes on every minor
  revision.
* Tue Jul 11 2017 ilya@ilya.pp.ua
- Reconfigurate spec-file
* Fri Apr  7 2017 jweberhofer@weberhofer.at
- removed -devel package which is of no use
- Simplified spec in the build section
- Enabled tests
* Sat Feb  4 2017 jweberhofer@weberhofer.at
- Upgrade to version 3.4.3
  - Fixes:
  * Avoid internal segfault.
  * Imagick::getRegistry() now throws an exception if the key does not exist,
    rather than terminating the program.
  * Prevent attempts to resize image to zero width or height, which is not
    supported by ImageMagick.
  * Fix compiling on Windows issue.
  * Imagick::transformImage and Imagick::orderedPosterizeImage now correctly
    excluded from
  * Bug 72311 - compiling against PHP 7.1.
  * Bug 72226 - regression for Imagick Exception classes being final on 7.x
  * Corrected reference of constants. Imagick::METRIC_MEANERRORPERPIXELMETRIC
    from MeanErrorPerPixelMetric to MeanErrorPerPixelErrorMetric.
    Imagick::METRIC_PEAKSIGNALTONOISERATIO from PeakSignalToNoiseRatioMetric
    to PeakSignalToNoiseRatioErrorMetric
  - Added:
  * function Imagick::setImageAlpha() which replaces Imagick::setOpacity()
  * function Imagick::identifyImageType() : int returns one of the
    Imagick::IMGTYPE_* constants
  * Imagick::INTERPOLATE_NEAREST_PIXEL for ImageMagick >= 7
  * In ImageMagick, the names of two filter constants were corrected to the
    standard spelling. Support for the new spelling has been added. The old
    constants are left in place for legacy support.
    Legacy: FILTER_HANNING, new name: FILTER_HANN
    Legacy: FILTER_WELSH, new name: FILTER_WELCH
  * The Imagick::IMGTYPE_*MATTE* constants are deprecated for ImageMagick 7.
  * Instead an appropriate Imagick::IMGTYPE_*MATTE* should be used.
    IMGTYPE_GRAYSCALEMATTE => IMGTYPE_GRAYSCALEALPHA
    IMGTYPE_PALETTEMATTE => IMGTYPE_PALETTEALPHA
    IMGTYPE_TRUECOLORALPHA => IMGTYPE_TRUECOLORMATTE
    IMGTYPE_COLORSEPARATIONALPHA => IMGTYPE_COLORSEPARATIONMATTE
    IMGTYPE_PALETTEBILEVELALPHA => IMGTYPE_PALETTEBILEVELMATTE
  * Several ALPHACHANNEL_* constants are only available in ImageMagick < 7
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_RESET", ResetAlphaChannel);
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_COPY", CopyAlphaChannel);
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_OPAQUE", OpaqueAlphaChannel);
  * Several ALPHACHANNEL_* constants are only available in ImageMagick >= 7.
    These constants re-use the values of the constants removed.
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_ON", OnAlphaChannel);
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_OFF", OffAlphaChannel);
    IMAGICK_REGISTER_CONST_LONG("ALPHACHANNEL_DISCRETE", DiscreteAlphaChannel);
* Tue Jan 10 2017 jweberhofer@weberhofer.at
- Upgrade to version 3.4.2
  * Bug: IM143 Correct ifdef around setOpacity and localContrastImage.
  * Bug: IM147 Imagick was Borging PHP's error handler.
* Mon Jun  6 2016 jweberhofer@weberhofer.at
- Minimum required versions are now PHP 5.4 and
  ImageMagick 6.5.3.10
- Update to version 3.4.1
  * Bug 71742 - arrays that contain data that is held by reference gives error.
  * Imagick::autoGammaImage([int channel = CHANNEL_ALL])
  * Imagick::autoOrient()
  * Imagick::compositeImageGravity(Imagick $image, int COMPOSITE_CONSTANT, int GRAVITY_CONSTANT)
  * Imagick::localContrastImage(float radius, float strength)
  * Imagick::DIRECTION_LEFT_TO_RIGHT
  * Imagick::DIRECTION_RIGHT_TO_LEFT
  * Imagick::SPARSECOLORMETHOD_MANHATTAN
  * ImagickDraw::getOpacity() : float
  * ImagickDraw::setOpacity(float opacity) :bool
  * ImagickDraw::getFontResolution() : array
  * ImagickDraw::setFontResolution(float x, float y) : bool
  * ImagickDraw::getTextDirection() : bool
  * ImagickDraw::setTextDirection(int direction) : bool
  * ImagickDraw::getBorderColor() : ImagickPixel
  * ImagickDraw::setBorderColor(ImagickPixel color) : bool
  * ImagickDraw::getDensity() : string|null
  * ImagickDraw::setDensity(string density_string) : bool
  * ImagickPixel::setColorFromPixel(ImagickPixel $srcPixel) : bool
- Version 3.4.0
  - Added support:
  * PHP 7
  * ImageMagick 7. Imagick can be compiled against either ImageMagick 6 or ImageMagick 7
    However it must be run with the exact same version it was compiled against. Trying
    to run Imagick with a different version of ImageMagick than it was compiled against
    is not supported. Please see http://nextgen.imagemagick.org/script/porting.php for
    more information about ImageMagick 7.
  - Minimum versions supported are now PHP >= 5.4.0 and ImageMagick >= 6.5.3-10.
    Earlier versions may continue to work, but they are no longer supported.
  - Added  methods:
  * Imagick::evaluateImages(int EVALUATE_CONSTANT) : Imagick
  * Imagick::subImageMatch() added parameters. The signature is now:
    Imagick::subimagematch(Imagick subimage[, array &$bestMatch[, float &similarity[,
    float $similarity_threshold = 0[, int $metric = ]]]])
    These parameters are only used when compiled against ImageMagick 7.
  * Imagick::similarityImage() which is an alias to Imagick::subImageMatch()
  * Imagick::getConfigureOptions
  * Imagick::getFeatures
  * Imagick::getHDRIEnabled
  * Imagick::setImageChannelMask (IM7 only)
  - Added IM7 constants:
  * Imagick::CHANNEL_READ_MASK
  * Imagick::CHANNEL_WRITE_MASK
  * Imagick::CHANNEL_META
  - Fixes:
  * Imagick::setImageWhitePoint, Imagick::setImageRedPrimary, Imagick::setImageGreenPrimary,
    Imagick::setImageBluePrimary now take 3 params when compiled against IM7.
  * Imagick::getImageWhitePoint, Imagick::getImageRedPrimary, Imagick::getImageGreenPrimary,
    Imagick::getImageBluePrimary now return 3 values when compiled against IM7.
  * wrong type for zend_parse_parameters.
  * Remove duplicated definitions of class constants.
  * Imagick::adaptiveResizeImage, Imagick::cropThumbnailImage Imagick::resizeImage,
    Imagick::scaleImage, and Imagick::thumbnailImage have all had a rounding bug fixed.
    An additional parameter has been added to each of them, 'bool $legacy'. If legacy
    is true, the calculations are done with the small rounding bug that existed in
    Imagick before 3.4.0. If false, the calculations should produce the same results as
    ImageMagick CLI does.
  * Imagick::colorizeImage() and Imagick::tintImage were using the wrong behaviour.
    It is now fixed and the legacy behaviour can still be used by passing a 3rd
    parameter of `true` to the function to indicate that the legacy behaviour is
    desired.
  * Imagick::importImagePixels regression fixed.
  * Imagick::subImageMatch use correct error metric in IM7
  * ImagickPixel::getColorQuantum, ImagickPixel::getColorValueQuantum and
    ImagickPixel::setColorValueQuantum now correctly use floats when Imagick
    was compiled against a HDRI version of ImageMagick
  * Imagick::exportImagePixels works for all storage types
  * Version number in extension header
* Fri Jan 29 2016 pgajdos@suse.com
- provides php-imagick symbol
* Tue Jan 12 2016 pgajdos@suse.com
- update to 3.3.0
* Tue Jan  7 2014 jweberhofer@weberhofer.at
- Update to 3.1.2
  * Fix ZTS build
  * Fix small memory leak in identifyImage
  * Added LICENSE
  * Added mimetype to identify image as per PECL bug 65037
  * Fixed type conversion error in newpseudoimage
  * Reworked identifyImage method
  * Fixed building against latest ImageMagick versions (#GH-2)
  * Fixed thumbnail resize bug (#GH-1)
  * Fixed building against latest PHP versions
- Fixed building on openSUSE 13.1+
- Cleaned up spec file
- Added seperate image file
- Cleaned up Changelog
- Splited off devel files to a seperate package
* Fri Aug 10 2012 crrodriguez@opensuse.org
- Update to RC2, fix build
* Tue Jun  7 2011 crrodriguez@opensuse.org
- fix build
* Mon Mar 21 2011 crrodriguez@opensuse.org
- Update to version 3.1.0b1
-  php5-imagick does not distribute a LICENSE [bnc#681129]
* Wed Feb  4 2009 crrodriguez@suse.de
- update to 2.2.2RC4
* Mon Jan 12 2009 crrodriguez@suse.de
- update to version 2.2.2RC2
- Added Imagick::setImageProgressmonitor and Imagick::orderedPosterizeImage
- Fixes http://imagemagick.org/discourse-server/viewtopic.php?f=18&t=12828
- Fixes error with empty exception messages
- Fixes PECL Bug #15332
- Fixed a possible memory leak in Imagick::convolveImage
* Mon Oct 27 2008 crrodriguez@suse.de
- update to 2.2.1 final, cosmetic version bump
* Mon Sep  8 2008 crrodriguez@suse.de
- update to version 2.2.1RC2
- Fixes a small memory leak when casting a string to ImagickPixel object
- Added new constants
- Added getImageChannelRange method
- Some cleaning up on the syntax
* Thu Jul 10 2008 crrodriguez@suse.de
- update to version 2.2.0
  * Major refactoring of the file structure
  * Fixes bugs related to the refactoring
* Fri Jun 13 2008 crrodriguez@suse.de
- update to version 2.2.0RC1
* Sun Mar  9 2008 crrodriguez@suse.de
- version 2.1.1 final
- Fixed a bug with fit parameter when scaling images with scaling ratio 1:1
  This is a minor BWC break. Scripts relying on incorrect behavior might need revisiting.
* Wed Feb 27 2008 crrodriguez@suse.de
- update to 2.1.1RC1 fixies build with ImageMagick 6.3.8-x
* Mon Feb 11 2008 crrodriguez@suse.de
- version 2.1.0 final
- Addded setImageAlphaChannel method
- Fixed sharpenImage parameters being reversed
- Fixed building with pre 5.2 versions
* Sun Jan 13 2008 crrodriguez@suse.de
- version 2.1.0RC3
- Fixes PECL Bug #12851
- Some major housekeeping changing numeral values to constants
* Tue Dec 25 2007 crrodriguez@suse.de
- version 2.1.0RC2
- Closes PECL Bugs #12463 and #12479
- Fixes the behavior of flattenImages and fximage
- Fixes incorrect thumbnail behavior
- Fixes a bug in Imagick::cropThumbnailImage
- Added new constant Imagick::NOISE_RANDOM
* Thu Nov 15 2007 crrodriguez@suse.de
- update to version 2.1.0RC1
- All methods that expect ImagickPixel now allow a string representing the color
- Added support for pixeliterator in all supported ImageMagick versions.
- ImagickPixelIterator now implements the iterator interface
- It is now possible to set the row with region iterator
- Added MAXPATHLEN checks for image reads/writes
- Added a fix to Imagick::cropThumbnailImage() to check if images are already at the desired size
- Fixed a memory leak in Imagick::getImageHistogram()
- Speed improvements to Imagick::cropThumbnailImage()
- Added interpolate constants
- Fixed ImagickPixel::getColor()
- Marked ImagickDraw::__construct() with ZEND_ACC_CTOR
- Added fit parameter and proportional scaling to:
- Imagick::adaptiveResizeImage()
- Imagick::scaleImage()
- Imagick::resizeImage()
- Added imagick.locale_fix ini setting to fix drawing bug on some locale
- Suppressed warnings in readImageFile and pingImageFile (PECL Bug #12367)
- Added methods:
- ImagickPixel::clone()
- ImagickPixel::getColorAsString()
- Imagick::mergeImageLayers()
- Imagick::paintFloodfillImage()
- Imagick::setFont()
- Imagick::getFont()
- Imagick::setPointsize()
- Imagick::getPointsize()
* Thu Oct 25 2007 crrodriguez@suse.de
- 2.0.1 final
- ImagickDraw::setFont and ImagickDraw::setFontFamily now allow only valid fonts
- Added IMAGICK_EXTVER and IMAGICK_EXTNUM constants
- Added check for empty or invalid pseudo format string in Imagick::newPseudoImage
- Fixed incorrect arg hinting for Imagick::compareImageChannels
* Wed Oct 17 2007 crrodriguez@suse.de
- 2.0.1RC1
- Added Imagick::distortImage and Imagick::setlastiterator
- Added optional fourth parameter to newImage to set the format when creating a new canvas
- Fixed fitting to zero size image in Imagick::thumbnailImage
- Fixed the destroy methods
- Most of the operations that read / add images to the stack move the iterator position to the last element
- Fixed memleaks in methods that replace the internal MagickWand* pointer
* Tue Oct  2 2007 crrodriguez@suse.de
- 2.0.0 final
- Added Imagick::extentImage
- Added Imagick::IMAGICK_VERSION_NUMBER and Imagick::IMAGICK_VERSION_STRING constants
- Fixed a possible crash in Imagick::newPseudoImage
* Tue Sep 25 2007 crrodriguez@suse.de
-  update to RC4
* Thu Sep 20 2007 crrodriguez@suse.de
- update to RC3
* Sat Sep  8 2007 crrodriguez@suse.de
- update to RC2
* Fri Aug 17 2007 crrodriguez@suse.de
- update to RC1
* Sun Jul  8 2007 judas_iscariote@shorewall.net
- Update to version 2.0.0b2, feature upgrade, backward incompatible.
* Fri Apr 13 2007 judas_iscariote@shorewall.net
- update to version 0.9.13
- Fixed compile error with newer versions of GraphicsMagick and ImageMagick
- Fixed assertion when using imagick_setfillcolor
- Fixed segfault when an empty blob is loaded
- Use new API for fetching support image formats / fonts
* Sat Jul  1 2006 soporte@onfocus.cl
- very first build
